@@ -21,6 +21,7 @@ class CVise:
 
         VERSION = "@cvise_VERSION@"
         GIT_VERSION = "@GIT_HASH@"
+        LLVM_VERSION = "@LLVM_VERSION@"
 
     pass_name_mapping = {
         "balanced": passes.BalancedPass,
@@ -58,7 +59,7 @@ class CVise:
 
     @classmethod
     def parse_pass_group_dict(cls, pass_group_dict, pass_options, external_programs, remove_pass,
-            clang_delta_std, not_c):
+            clang_delta_std, not_c, no_renaming):
         pass_group = {}
         removed_passes = set(remove_pass.split(",")) if remove_pass else set()
 
@@ -101,6 +102,8 @@ class CVise:
 
                 if not_c and "c" in pass_dict and pass_dict["c"]:
                     continue
+                elif no_renaming and "renaming" in pass_dict and pass_dict["renaming"]:
+                    continue
 
                 pass_instance.clang_delta_std = clang_delta_std
                 pass_group[category].append(pass_instance)
