@@ -37,13 +37,16 @@ class BinaryState:
     def end(self):
         return min(self.index + self.chunk, self.instances)
 
+    def real_chunk(self):
+        return self.end() - self.index
+
     def advance(self):
         self = self.copy()
         original_index = self.index
         self.index += self.chunk
         if self.index >= self.instances:
             self.chunk = int(self.chunk / 2)
-            if self.chunk <= 1:
+            if self.chunk < 1:
                 return None
             logging.debug("granularity reduced to {}".format(self.chunk))
             self.index = 0
@@ -80,7 +83,10 @@ class AbstractPass:
         program = self.external_programs[name]
         if not program:
             return False
-        return shutil.which(program) is not None
+        result = shutil.which(program) is not None
+        if not result:
+            logging.error("cannot find external program {}".format(name))
+        return result
 
     def check_prerequisites(self):
         raise NotImplementedError("Class {} has not implemented 'check_prerequisites'!".format(type(self).__name__))
@@ -111,8 +117,10 @@ class ProcessEventNotifier:
     def __init__(self, pid_queue):
         self.pid_queue = pid_queue
 
-    def run_process(self, cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE):
-        proc = subprocess.Popen(cmd, stdout=stdout, stderr=stderr, universal_newlines=True, encoding='utf8')
+    def run_process(self, cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False):
+        if shell:
+            assert isinstance(cmd, str)
+        proc = subprocess.Popen(cmd, stdout=stdout, stderr=stderr, universal_newlines=True, encoding='utf8', shell=shell)
         if self.pid_queue:
             self.pid_queue.put(ProcessEvent(proc.pid, ProcessEventType.STARTED))
         stdout, stderr = proc.communicate()
