@@ -8,7 +8,7 @@ from cvise.passes.abstract import AbstractPass, PassResult
 
 class ClangPass(AbstractPass):
     def check_prerequisites(self):
-        return shutil.which(self.external_programs["clang_delta"]) is not None
+        return self.check_external_program("clang_delta")
 
     def new(self, test_case):
         return 1
@@ -24,7 +24,7 @@ class ClangPass(AbstractPass):
         with tempfile.NamedTemporaryFile(mode="w", delete=False, dir=tmp) as tmp_file:
             args = [self.external_programs["clang_delta"], "--transformation={}".format(self.arg), "--counter={}".format(state)]
             if self.clang_delta_std:
-                args.apend('--std={}'.format(self.clang_delta_std))
+                args.append('--std={}'.format(self.clang_delta_std))
             cmd = args + [test_case]
 
             logging.debug(" ".join(cmd))
