@@ -111,10 +111,12 @@ words, running these commands:
   DIR=`mktemp -d`
   cp {test_cases} $DIR
   cd $DIR
-  {test} {test_cases}
+  {test}
   echo $?
 
 should result in "0" being echoed to the terminal.
+Please ensure that the test script takes no arguments; it should be hard-coded to refer
+to the same file that is passed as an argument to C-Vise.
 
 See "cvise.py --help" for more information.""".format(test_cases=" ".join(self.test_cases), test=self.test)
         return message
