@@ -7,6 +7,7 @@ import math
 import multiprocessing
 import os
 import os.path
+import pebble
 import platform
 import shutil
 import signal
@@ -17,7 +18,6 @@ import weakref
 
 import concurrent.futures
 from concurrent.futures import wait, FIRST_COMPLETED, TimeoutError
-from pebble import ProcessPool
 from multiprocessing import Queue, Manager
 
 from .. import CVise
@@ -30,6 +30,9 @@ from .error import InvalidTestCaseError
 from .error import PassBugError
 from .error import ZeroSizeError
 
+# change default Pebble sleep unit for faster response
+pebble.common.SLEEP_UNIT = 0.01
+
 def rmfolder(name):
     assert 'cvise' in name
     try:
@@ -108,15 +111,15 @@ class TestEnvironment:
             # this can happen when we clean up temporary files for cancelled processes
             pass
         except Exception as e:
-            print('Should not happen: ' + str(e))
+            print('Unexpected TestEnvironment::run failure: ' + str(e))
         finally:
             return self
 
     def run_test(self):
         try:
             os.chdir(self.folder)
-            cmd = [self.test_script]
-            _, _, returncode = ProcessEventNotifier(self.pid_queue).run_process(cmd)
+            _, _, returncode = ProcessEventNotifier(self.pid_queue).run_process(self.test_script, shell=True,
+                    stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
         finally:
             os.chdir(self.pwd)
         return returncode
@@ -235,9 +238,10 @@ class TestManager:
             logging.debug("Please consider tarring up {} and creating an issue at https://github.com/marxin/cvise/issues and we will try to fix the bug.".format(crash_dir))
 
         with open(os.path.join(crash_dir, "PASS_BUG_INFO.TXT"), mode="w") as info_file:
-            info_file.write("{}\n".format(CVise.Info.PACKAGE_STRING))
-            info_file.write("{}\n".format(CVise.Info.GIT_VERSION))
-            info_file.write("{}\n".format(platform.uname()))
+            info_file.write("Package: %s\n" % CVise.Info.PACKAGE_STRING)
+            info_file.write("Git version: %s\n" % CVise.Info.GIT_VERSION)
+            info_file.write("LLVM version: %s\n" % CVise.Info.LLVM_VERSION)
+            info_file.write("System: %s\n" % str(platform.uname()))
             info_file.write(PassBugError.MSG.format(self.current_pass, problem, test_env.state, crash_dir))
 
         if self.die_on_pass_bug:
@@ -382,7 +386,7 @@ class TestManager:
     def run_parallel_tests(self):
         assert not self.futures
         assert not self.temporary_folders
-        with ProcessPool(max_workers=self.parallel_tests) as pool:
+        with pebble.ProcessPool(max_workers=self.parallel_tests) as pool:
             order = 1
             self.timeout_count = 0
             while self.state != None:
@@ -467,13 +471,13 @@ class TestManager:
 
                 success_env = self.run_parallel_tests()
                 self.kill_pid_queue()
-                if not success_env:
-                    self.remove_root()
-                    break
 
-                self.process_result(success_env)
+                if success_env:
+                    self.process_result(success_env)
                 self.release_folders()
                 self.futures.clear()
+                if not success_env:
+                    break
 
             # Cache result of this pass
             if not self.no_cache:
@@ -487,8 +491,6 @@ class TestManager:
         self.pass_statistic.stop(self.current_pass)
 
     def process_result(self, test_env):
-        logging.debug("Process result")
-
         if self.print_diff:
             diff_str = self.diff_files(self.current_test_case, test_env.test_case_path)
             logging.info(diff_str)
